Struct rosu_map::section::hit_objects::HitObjects
source · pub struct HitObjects {Show 24 fields
pub audio_file: String,
pub audio_lead_in: f64,
pub preview_time: i32,
pub default_sample_bank: SampleBank,
pub default_sample_volume: i32,
pub stack_leniency: f32,
pub mode: GameMode,
pub letterbox_in_breaks: bool,
pub special_style: bool,
pub widescreen_storyboard: bool,
pub epilepsy_warning: bool,
pub samples_match_playback_rate: bool,
pub countdown: CountdownType,
pub countdown_offset: i32,
pub hp_drain_rate: f32,
pub circle_size: f32,
pub overall_difficulty: f32,
pub approach_rate: f32,
pub slider_multiplier: f64,
pub slider_tick_rate: f64,
pub background_file: String,
pub breaks: Vec<BreakPeriod>,
pub control_points: ControlPoints,
pub hit_objects: Vec<HitObject>,
}Expand description
Struct containing all data from a .osu file’s [HitObjects], [Events],
[Difficulty], [TimingPoints] and [General] section.
Fields
audio_file: Stringaudio_lead_in: f64preview_time: i32default_sample_bank: SampleBankdefault_sample_volume: i32stack_leniency: f32mode: GameModeletterbox_in_breaks: boolspecial_style: boolwidescreen_storyboard: boolepilepsy_warning: boolsamples_match_playback_rate: boolcountdown: CountdownTypecountdown_offset: i32hp_drain_rate: f32circle_size: f32overall_difficulty: f32approach_rate: f32slider_multiplier: f64slider_tick_rate: f64background_file: Stringbreaks: Vec<BreakPeriod>control_points: ControlPointshit_objects: Vec<HitObject>Trait Implementations
sourceimpl Clone for HitObjects
impl Clone for HitObjects
sourcefn clone(&self) -> HitObjects
fn clone(&self) -> HitObjects
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for HitObjects
impl Debug for HitObjects
sourceimpl DecodeBeatmap for HitObjects
impl DecodeBeatmap for HitObjects
type Error = ParseHitObjectsError
type Error = ParseHitObjectsError
Error type in case something goes wrong while parsing. Read more
type State = HitObjectsState
type State = HitObjectsState
The parsing state which will be updated on each line and turned into
Self at the end.sourcefn parse_general(state: &mut Self::State, line: &str) -> Result<(), Self::Error>
fn parse_general(state: &mut Self::State, line: &str) -> Result<(), Self::Error>
Update the state based on a line of the
[General] section.sourcefn parse_editor(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
fn parse_editor(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
Update the state based on a line of the
[Editor] section.sourcefn parse_metadata(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
fn parse_metadata(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
Update the state based on a line of the
[Metadata] section.sourcefn parse_difficulty(
state: &mut Self::State,
line: &str
) -> Result<(), Self::Error>
fn parse_difficulty( state: &mut Self::State, line: &str ) -> Result<(), Self::Error>
Update the state based on a line of the
[Difficulty] section.sourcefn parse_events(state: &mut Self::State, line: &str) -> Result<(), Self::Error>
fn parse_events(state: &mut Self::State, line: &str) -> Result<(), Self::Error>
Update the state based on a line of the
[Events] section.sourcefn parse_timing_points(
state: &mut Self::State,
line: &str
) -> Result<(), Self::Error>
fn parse_timing_points( state: &mut Self::State, line: &str ) -> Result<(), Self::Error>
Update the state based on a line of the
[TimingPoints] section.sourcefn parse_colors(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
fn parse_colors(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
Update the state based on a line of the
[Colours] section.sourcefn parse_hit_objects(
state: &mut Self::State,
line: &str
) -> Result<(), Self::Error>
fn parse_hit_objects( state: &mut Self::State, line: &str ) -> Result<(), Self::Error>
Update the state based on a line of the
[HitObjects] section.sourcefn parse_variables(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
fn parse_variables(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
Update the state based on a line of the
[Variables] section.sourcefn parse_catch_the_beat(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
fn parse_catch_the_beat(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
Update the state based on a line of the
[CatchTheBeat] section.sourcefn parse_mania(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
fn parse_mania(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
Update the state based on a line of the
[Mania] section.sourcefn should_skip_line(line: &str) -> bool
fn should_skip_line(line: &str) -> bool
Whether a line should not be forwarded to the parsing methods.
sourceimpl Default for HitObjects
impl Default for HitObjects
sourceimpl From<HitObjects> for Beatmap
impl From<HitObjects> for Beatmap
sourcefn from(hit_objects: HitObjects) -> Self
fn from(hit_objects: HitObjects) -> Self
Converts to this type from the input type.
sourceimpl From<HitObjectsState> for HitObjects
impl From<HitObjectsState> for HitObjects
sourcefn from(state: HitObjectsState) -> Self
fn from(state: HitObjectsState) -> Self
Converts to this type from the input type.
sourceimpl PartialEq for HitObjects
impl PartialEq for HitObjects
sourcefn eq(&self, other: &HitObjects) -> bool
fn eq(&self, other: &HitObjects) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl StructuralPartialEq for HitObjects