Struct rosu_map::section::timing_points::TimingPoints
source · pub struct TimingPoints {Show 15 fields
pub audio_file: String,
pub audio_lead_in: f64,
pub preview_time: i32,
pub default_sample_bank: SampleBank,
pub default_sample_volume: i32,
pub stack_leniency: f32,
pub mode: GameMode,
pub letterbox_in_breaks: bool,
pub special_style: bool,
pub widescreen_storyboard: bool,
pub epilepsy_warning: bool,
pub samples_match_playback_rate: bool,
pub countdown: CountdownType,
pub countdown_offset: i32,
pub control_points: ControlPoints,
}Expand description
Struct containing all data from a .osu file’s [TimingPoints] and
[General] section.
Fields
audio_file: Stringaudio_lead_in: f64preview_time: i32default_sample_bank: SampleBankdefault_sample_volume: i32stack_leniency: f32mode: GameModeletterbox_in_breaks: boolspecial_style: boolwidescreen_storyboard: boolepilepsy_warning: boolsamples_match_playback_rate: boolcountdown: CountdownTypecountdown_offset: i32control_points: ControlPointsTrait Implementations
sourceimpl Clone for TimingPoints
impl Clone for TimingPoints
sourcefn clone(&self) -> TimingPoints
fn clone(&self) -> TimingPoints
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for TimingPoints
impl Debug for TimingPoints
sourceimpl DecodeBeatmap for TimingPoints
impl DecodeBeatmap for TimingPoints
type Error = ParseTimingPointsError
type Error = ParseTimingPointsError
Error type in case something goes wrong while parsing. Read more
type State = TimingPointsState
type State = TimingPointsState
The parsing state which will be updated on each line and turned into
Self at the end.sourcefn parse_general(state: &mut Self::State, line: &str) -> Result<(), Self::Error>
fn parse_general(state: &mut Self::State, line: &str) -> Result<(), Self::Error>
Update the state based on a line of the
[General] section.sourcefn parse_editor(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
fn parse_editor(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
Update the state based on a line of the
[Editor] section.sourcefn parse_metadata(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
fn parse_metadata(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
Update the state based on a line of the
[Metadata] section.sourcefn parse_difficulty(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
fn parse_difficulty(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
Update the state based on a line of the
[Difficulty] section.sourcefn parse_events(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
fn parse_events(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
Update the state based on a line of the
[Events] section.sourcefn parse_timing_points(
state: &mut Self::State,
line: &str
) -> Result<(), Self::Error>
fn parse_timing_points( state: &mut Self::State, line: &str ) -> Result<(), Self::Error>
Update the state based on a line of the
[TimingPoints] section.sourcefn parse_colors(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
fn parse_colors(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
Update the state based on a line of the
[Colours] section.sourcefn parse_hit_objects(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
fn parse_hit_objects(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
Update the state based on a line of the
[HitObjects] section.sourcefn parse_variables(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
fn parse_variables(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
Update the state based on a line of the
[Variables] section.sourcefn parse_catch_the_beat(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
fn parse_catch_the_beat(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
Update the state based on a line of the
[CatchTheBeat] section.sourcefn parse_mania(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
fn parse_mania(_: &mut Self::State, _: &str) -> Result<(), Self::Error>
Update the state based on a line of the
[Mania] section.sourcefn should_skip_line(line: &str) -> bool
fn should_skip_line(line: &str) -> bool
Whether a line should not be forwarded to the parsing methods.
sourceimpl Default for TimingPoints
impl Default for TimingPoints
sourceimpl From<TimingPoints> for Beatmap
impl From<TimingPoints> for Beatmap
sourcefn from(timing_points: TimingPoints) -> Self
fn from(timing_points: TimingPoints) -> Self
Converts to this type from the input type.
sourceimpl From<TimingPointsState> for TimingPoints
impl From<TimingPointsState> for TimingPoints
sourcefn from(state: TimingPointsState) -> Self
fn from(state: TimingPointsState) -> Self
Converts to this type from the input type.
sourceimpl PartialEq for TimingPoints
impl PartialEq for TimingPoints
sourcefn eq(&self, other: &TimingPoints) -> bool
fn eq(&self, other: &TimingPoints) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl StructuralPartialEq for TimingPoints