ControlPoint

Trait ControlPoint 

pub trait ControlPoint<C> {
    // Required methods
    fn check_already_existing(&self, control_points: &C) -> bool;
    fn add(self, control_points: &mut C);
}
A control point to be added into a collection of type C.

Required Methods

fn check_already_existing(&self, control_points: &C) -> bool

Whether self is redundant w.r.t. an already existing control point.

fn add(self, control_points: &mut C)

Adding the control point into the collection.

Note that control points should be inserted in order by time.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors