Module rosu_map::util

source ·
Various utility types for usage in and around this library.

Structs

  • Auxiliary struct for parsing key-value pairs.
  • Simple (x, y) coordinate / vector

Enums

Constants

Traits

  • Parses a &str to a number and makes sure it doesn’t exceed a limit.
  • Extension methods for str which are commonly used in and around this library.