Various utility types for usage in and around this library.
Structs
- Auxiliary struct for parsing key-value pairs.
- Simple
(x, y)coordinate / vector
Enums
- All the ways that parsing with
ParseNumbercan fail.
Constants
- The default limit when parsing via
ParseNumber.
Traits
- Parses a
&strto a number and makes sure it doesn’t exceed a limit. - Extension methods for
strwhich are commonly used in and around this library.